<?php
// $Id: live_person.admin.inc,v 1.1 2009/12/11 19:11:07 nicholasalipaz Exp $

/**
 * @file
 * Administrative page callbacks for the live_person module.
 */

/**
 * Implementation of hook_admin_settings() for configuring the module
 */
function live_person_admin_settings_form(&$form_state) {
  $form['account'] = array(
    '#type' => 'fieldset',
    '#title' => t('General settings'),
    '#collapsible' => FALSE,
  );
  
  $form['account']['live_person_account'] = array(
    '#type' => 'textfield',
    '#title' => t('Live Person account number'),
    '#default_value' => variable_get('live_person_account', ''),
    '#size' => 15,
    '#maxlength' => 20,
    '#required' => TRUE,
    '#description' => t('The account number is unique to the websites domain.'),
  );
  
  $access = user_access('use PHP for live person visibility');
  $visibility = variable_get('live_person_visibility', 0);
  $pages = variable_get('live_person_pages', '');

  if ($visibility == 2 && !$access) {
    $form['page_vis_settings'] = array();
    $form['page_vis_settings']['visibility'] = array('#type' => 'value', '#value' => 2);
    $form['page_vis_settings']['pages'] = array('#type' => 'value', '#value' => $pages);
  }
  else {
    $options = array(t('Add to every page except the listed pages.'), t('Add to the listed pages only.'));
    $description = t("Enter one page per line as Drupal paths. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.", array('%blog' => 'blog', '%blog-wildcard' => 'blog/*', '%front' => '<front>'));

    if ($access) {
      $options[] = t('Add if the following PHP code returns <code>TRUE</code> (PHP-mode, experts only).');
      $description .= ' '. t('If the PHP-mode is chosen, enter PHP code between %php. Note that executing incorrect PHP-code can break your Drupal site.', array('%php' => '<?php ?>'));
    }
    $form['page_vis_settings']['live_person_visibility'] = array(
      '#type' => 'radios',
      '#title' => t('Add tracking to specific pages'),
      '#options' => $options,
      '#default_value' => $visibility,
    );
    $form['page_vis_settings']['live_person_pages'] = array(
      '#type' => 'textarea',
      '#title' => t('Pages'),
      '#default_value' => $pages,
      '#description' => $description,
      '#wysiwyg' => FALSE,
    );
  }

  return system_settings_form($form);
}

function live_person_admin_settings_form_validate($form, &$form_state) {
  if (empty($form_state['values']['live_person_account'])) {
    form_set_error('live_person_account', t('A valid Live Person account number is needed.'));
  }
}
